aboutsummaryrefslogtreecommitdiff
path: root/engines/titanic/pet_control/pet_text.h
diff options
context:
space:
mode:
authorPaul Gilbert2016-04-25 20:38:23 -0400
committerPaul Gilbert2016-07-10 16:12:02 -0400
commit1512545f28c805fd4083be746220f77b72463130 (patch)
tree9d9e6ea5e6499d0e90b5bebeba3d58e3731b3455 /engines/titanic/pet_control/pet_text.h
parent36faf0890fec6bab90531ade42c0eb924b31b64a (diff)
downloadscummvm-rg350-1512545f28c805fd4083be746220f77b72463130.tar.gz
scummvm-rg350-1512545f28c805fd4083be746220f77b72463130.tar.bz2
scummvm-rg350-1512545f28c805fd4083be746220f77b72463130.zip
TITANIC: Resolve color handling code in CPetText
Diffstat (limited to 'engines/titanic/pet_control/pet_text.h')
-rw-r--r--engines/titanic/pet_control/pet_text.h15
1 files changed, 9 insertions, 6 deletions
diff --git a/engines/titanic/pet_control/pet_text.h b/engines/titanic/pet_control/pet_text.h
index 24c4e949b6..2213c631d6 100644
--- a/engines/titanic/pet_control/pet_text.h
+++ b/engines/titanic/pet_control/pet_text.h
@@ -31,7 +31,7 @@ namespace Titanic {
class CPetText {
struct ArrayEntry {
CString _string1;
- CString _string2;
+ CString _rgb;
CString _string3;
};
private:
@@ -64,8 +64,6 @@ private:
void freeArrays();
- void setArrayStr2(uint idx, int val1, int val2, int val3);
-
/**
* Merges the strings in the strings array
*/
@@ -120,12 +118,17 @@ public:
/**
* Set text color
*/
- void setColor(int val1, uint col);
+ void setColor(uint col);
/**
* Set text color
*/
- void setColor(uint col);
+ void setLineColor(uint lineNum, byte r, byte g, byte b);
+
+ /**
+ * Set the color for a line
+ */
+ void setLineColor(uint lineNum, uint col);
/**
* Sets the maximum number of characters per line
@@ -120,12 +118,17 @@ public:
/**
- * Set text color
+ * Set the color for a line
*/